use ::games::deck;

// Verify random draw wont effect anything, other than performance
#[test]
fn draw_many() {
    // Over Draw
    {
        let mut d1 = deck::Deck::new(None, true);
        let mut d2 = deck::Deck::new(None, false);

        assert_eq!(52usize, d1.draw_many(128).len());
        // Over Draw
        assert_eq!(52usize, d2.draw_many(128).len());
        assert!(d2.cards.is_empty());
        assert!(d1.cards.is_empty());
    }
    // Draw only a few
    {
        let mut d1 = deck::Deck::new(None, true);
        assert_eq!(28usize, d1.draw_many(28).len());
        assert_eq!(24usize, d1.cards.len());
    }
    {
        let mut d2 = deck::Deck::new(None, false);
        assert_eq!(28usize, d2.draw_many(28).len());
        assert_eq!(24usize, d2.cards.len());
    }
}

#[test]
fn draw() {
    let mut d1 = deck::Deck::new(None, true);
    let mut d2 = deck::Deck::new(None, false);
    // Empty the deck by drawing cards (No errors should be raised)
    for _ in 0..d1.cards.len() {
        d1.draw().expect("Expected to get a card");
    }
    for _ in 0..d2.cards.len() {
        d2.draw().expect("Expected to get a card");
    }
    // Verify they are empty
    assert!(d1.cards.is_empty());
    assert!(d2.cards.is_empty());
    // Verify draw doesnt panic, but throws an error
    d1.draw().expect_err("Expected an error");
    d2.draw().expect_err("Expected an error");
}
